// -------------------------------------------------------------------
//                               EXQSLV
//
//    This program reads a quadratic problem from MPS files, solves
//    the problem, and prints the solution.
//
// -------------------------------------------------------------------

#include <stdio.h>
#include <stdarg.h>
#include <string.h>
#include <stdlib.h>
#include <math.h>
#include <assert.h>
#include <iostream.h>
#include "ekk_c_api.h"


int main()
{
#ifndef EKK_THREADSAFE
  // Initialize OSL environment
    EKKContext * env;
    env = ekk_initializeContext();
  
    // Create an OSL model "test"
    EKKModel * test = ekk_newModel(env,NULL);

    // Read model data from MPS file
    int rtcod = ekk_importModel(test,"share2qp.mps");

    // Read quadratic model data from MPS file
    rtcod = ekk_importQuadraticData(test,"share2qp.mps");

    // Solve using simplex method
    rtcod = ekk_quadraticSimplex(test,1);

    // Set to print both primal/dual solutions
    rtcod = ekk_setIprtinfomask(test,63);

    // Print the solution
    rtcod = ekk_printSolution(test);

    // Delete the model
    rtcod = ekk_deleteModel(test);
  
    // OSL Destructor
    ekk_endContext(env);

#else
    printf("ekk_quadraticSimplex not yet threadsafe\n");
#endif
    return 0;
}
