// **********************************************************************
//
//                           EXSENS1
//
//  This program reads an MPS file containing an LP model, performs
//  presolve processing, solves it, and performs sensitivity analysis
//  on the objective function coefficients and row and column bounds.
//  ekk_printSolution is used to print the results.
//
// **********************************************************************

#include <string.h>
#include <stdlib.h>
#include <math.h>
#include <assert.h>
#include "ekkc.h"
#include "ekk_c_api.h"

int main()
{
    // Initialize OSL environment
    EKKContext * env;
    env = ekk_initializeContext();

    // Create an OSL model "test"
    EKKModel * test;
    test = ekk_newModel(env,NULL);

    // Read model data from MPS file
    int rtcod = ekk_importModel(test,"exlp1.mps");

    // Presolve the problem
    rtcod = ekk_preSolve(test,3,"presolve3");

    // Solve using simplex method
    rtcod = ekk_primalSimplex(test,2);

    // Postsolve to map back to original variables
    rtcod = ekk_postSolve(test,"presolve3");

    // Solve again to ensure dual feasibility
    rtcod = ekk_primalSimplex(test,3);
    
#if 0
    // Create work space to be able to make V2 type calls   
    double * dspace = (double*)malloc(3000000*sizeof(double));
    ekk_loadDspace(test, dspace, 3000000);

    // Perform sensitivity analysis on the objective function
    long rc;
    ekksobj(&rc,dspace);

    // Perform sensitivity analysis on row and column bounds
    ekksbnd(&rc,dspace,3,1);

    // Print the solution
    ekkprts(&rc,dspace);

    // Copy data from V2 work space to V3 object and free V2 work space
    rtcod = ekk_unloadDspace(test,dspace);
    free(dspace);
#else
    EKKSensitivityInfo si = ekk_sensitivityInfo(test);
#endif
    
    // Print the solution
    rtcod = ekk_printSolution(test);

    // Delete the model
    rtcod = ekk_deleteModel(test);

    // OSL Destructor
    ekk_endContext(env);

    return 0;
}
