// -------------------------------------------------------------------
//                             EXSOS
//
// This program reads a MIP problem from an MPS file, identifies
// SOS Types 1 and 3 in the model, solves the problem with the branch-and-
// bound method by exploiting special SOS branching tenchniques.
// -------------------------------------------------------------------

#include <string.h>
#include <stdlib.h>
#include <stdio.h>
#include <stdarg.h>
#include <math.h>
#include <assert.h>
#include "ekk_c_api.h"

int main()
{
    // Initialize OSL environment
    EKKContext * env;
    env = ekk_initializeContext();

    // Create a model
    EKKModel * binmodel;
    binmodel = ekk_newModel(env,NULL);

    // Turn all OSL messages off
    int rtcod = ekk_messagesPrintOff(binmodel,1,9999);

    // Set to print primal and dual solutions
    rtcod = ekk_setIprtinfomask(binmodel,63);

    // Print values of function parameters upon entry
    ekk_setPrinting(binmodel,1,1,0);

    // Turn all OSL messages back on
    rtcod = ekk_messagesPrintOn(binmodel,1,9999);

    // Read model data from an MPS file w/name p0040.mps
    rtcod = ekk_importModel(binmodel,"p0040.mps");

    // Increase maximum allowable number of rows by 1000
    rtcod = ekk_setImaxrows(binmodel,ekk_getImaxrows(binmodel)+1000);

    // Solve the LP-relaxation of the model by either primal or 
    // dual simplex method
    rtcod = ekk_eitherSimplex(binmodel);

    // Identify SOS 1 or 3 structures in the model
    rtcod = ekk_findSOS(binmodel);

    // Solve the integer model by branch-and-bound
    rtcod = ekk_branchAndBound(binmodel,"matrix3","basis3");

    // Remove files
    remove("matrix3"); 
    remove("basis3");

    // Print the solution
    rtcod = ekk_printSolution(binmodel);

    // Destroy the model; free up memory
    rtcod = ekk_deleteModel(binmodel);

    // OSL Destructor
    ekk_endContext(env);

    return 0;
}
